@@ -87,7 +87,9 @@ def get_executable_code(file_path: str) -> str:
 	language = language_dict[file_path.split('.')[-1][2:]]
 
 	# Load the language map.
-	with open("keywords/" + language + ".yml", 'rb') as f:
+	directory, _ = os.path.split(__file__)
+	DATA_PATH = os.path.join(directory, "keywords", language + ".yml")
+	with open(DATA_PATH, 'rb') as f:
 		yml_lines = [line.decode('utf-8').strip() for line in f]
 		keywords = {}
 		for yml_line in yml_lines:
